@@ -4,7 +4,7 @@ use cargo::ops;
 pub fn cli() -> App {
     subcommand("logout")
         .about("Remove an API token from the registry locally")
-        .arg(opt("quiet", "No output printed to stdout").short("q"))
+        .arg(opt("quiet", "Do not print cargo log messages").short("q"))
         .arg(opt("registry", "Registry to use").value_name("REGISTRY"))
         .after_help("Run `cargo help logout` for more detailed information.\n")
 }
