@@ -5,7 +5,7 @@ use cargo::ops::{self, OwnersOptions};
 pub fn cli() -> App {
     subcommand("owner")
         .about("Manage the owners of a crate on the registry")
-        .arg(opt("quiet", "No output printed to stdout").short("q"))
+        .arg(opt("quiet", "Do not print cargo log messages").short("q"))
         .arg(Arg::with_name("crate"))
         .arg(
             multi_opt(
@@ -27,15 +27,7 @@ pub fn cli() -> App {
         .arg(opt("index", "Registry index to modify owners for").value_name("INDEX"))
         .arg(opt("token", "API token to use when authenticating").value_name("TOKEN"))
         .arg(opt("registry", "Registry to use").value_name("REGISTRY"))
-        .after_help(
-            "\
-This command will modify the owners for a crate on the specified registry (or
-default). Owners of a crate can upload new versions and yank old versions.
-Explicitly named owners can also modify the set of owners, so take care!
-
-    See https://doc.rust-lang.org/cargo/reference/publishing.html#cargo-owner
-    for detailed documentation and troubleshooting.",
-        )
+        .after_help("Run `cargo help owner` for more detailed information.\n")
 }
 
 pub fn exec(config: &mut Config, args: &ArgMatches<'_>) -> CliResult {
