@@ -4,7 +4,8 @@ use crate::command_prelude::*;
 pub fn cli() -> App {
     subcommand("version")
         .about("Show version information")
-        .arg(opt("quiet", "No output printed to stdout").short("q"))
+        .arg(opt("quiet", "Do not print cargo log messages").short("q"))
+        .after_help("Run `cargo help version` for more detailed information.\n")
 }
 
 pub fn exec(config: &mut Config, args: &ArgMatches<'_>) -> CliResult {
