@@ -84,8 +84,6 @@ fn run_unit_tests(
         script_meta,
     } in compilation.tests.iter()
     {
-        let test = unit.target.name().to_string();
-
         let test_path = unit.target.src_path().path().unwrap();
         let exe_display = if let TargetKind::Test = unit.target.kind() {
             format!(
@@ -117,20 +115,17 @@ fn run_unit_tests(
 
         let result = cmd.exec();
 
-        match result {
-            Err(e) => {
-                let e = e.downcast::<ProcessError>()?;
-                errors.push((
-                    unit.target.kind().clone(),
-                    test.clone(),
-                    unit.pkg.name().to_string(),
-                    e,
-                ));
-                if !options.no_fail_fast {
-                    break;
-                }
+        if let Err(e) = result {
+            let e = e.downcast::<ProcessError>()?;
+            errors.push((
+                unit.target.kind().clone(),
+                unit.target.name().to_string(),
+                unit.pkg.name().to_string(),
+                e,
+            ));
+            if !options.no_fail_fast {
+                break;
             }
-            Ok(()) => {}
         }
     }
 
